@@ -258,7 +258,6 @@ class Regression:
         if self.predictor == 'all':
             self.pred_mode = 'all'
             self._fitall()
-            return
         if self.predictor == 'ann':
             self.parameters, self.regressor, self.regressor_wrap = regressionPredictor(
                 self.predictor, self.params, self.X_train, self.X_val, self.y_train, self.y_val, self.epochs, self.hidden_layers,
@@ -402,6 +401,7 @@ class Regression:
         print('Complete [', u'\u2713', ']\n')
         self.end = time.time()
         print('Time Elapsed : ', self.end - self.start, 'seconds \n')
+        return
 
     def __tuner(self, all_mode=False):
         if not all_mode:
@@ -426,7 +426,7 @@ class Regression:
                         - "RMSE" - Root Mean Square
                         - "YPred" - Array for Prediction set
                         ]
-            [pd.dataframe] : [Dataset containing accuracy and best_params 
+            [dataframe] : [Dataset containing accuracy and best_params 
                             for all predictors only when predictor = 'all' is used
                             ]
         """
