@@ -67,8 +67,6 @@ parameters_dt_3 = [{
 }]
 
 
-
-
 parameters_rfr_1 = [{
     'n_estimators': [100, 200, 300, 400, 500, 750, 1000],
     'max_depth': [4,  6,  8,  10,  12,  20,  40, 70],
@@ -95,40 +93,99 @@ parameters_rfr_3 = [{
 }]
 
 
-
-
 parameters_gbr_1 = [{
-    'learning_rate': [0.02,0.04],
-    'subsample'    : [ 0.5, 0.2, 0.1],
+    'learning_rate': [0.02, 0.04],
+    'subsample': [0.5, 0.2, 0.1],
     'n_estimators': [100, 200, 300, 400, 500, 750, 1000],
-    'max_depth'    : [4,6],
+    'max_depth': [4, 6],
     'loss': ['ls', 'lad'],
-    'criterion' : ['mse', 'mae'],
+    'criterion': ['mse', 'mae'],
     'min_samples_split': [8, 10],
     'min_samples_leaf': [3, 4],
-                 }]
+}]
 parameters_gbr_2 = [{
-    'learning_rate': [0.02,0.03,0.04],
-    'subsample'    : [0.5, 0.2, 0.1],
+    'learning_rate': [0.02, 0.03, 0.04],
+    'subsample': [0.5, 0.2, 0.1],
     'n_estimators': [50, 100, 150, 200, 250, 300, 400, 500, 700, 900, 1000],
-    'max_depth'    : [4,6,8],
+    'max_depth': [4, 6, 8],
     'loss': ['ls', 'lad', 'huber'],
-    'criterion' :['friedman_mse', 'mse'],
+    'criterion':['friedman_mse', 'mse'],
     'min_samples_split': [8, 10, 12],
     'min_samples_leaf': [3, 4],
-                 }]
+}]
 parameters_gbr_3 = [{
-    'learning_rate': [0.01,0.02,0.03,0.04],
-    'subsample'    : [0.9, 0.5, 0.2, 0.1],
+    'learning_rate': [0.01, 0.02, 0.03, 0.04],
+    'subsample': [0.9, 0.5, 0.2, 0.1],
     'n_estimators': [50, 100, 150, 200, 250, 300, 400, 500, 600, 700, 800, 900, 1000],
-    'max_depth'    : [4,6,8,10],
+    'max_depth': [4, 6, 8, 10],
     'loss': ['ls', 'lad', 'huber', 'quantile'],
-    'criterion' : ['friedman_mse', 'mse', 'mae'],
+    'criterion': ['friedman_mse', 'mse', 'mae'],
     'min_samples_split': [8, 10, 12],
     'min_samples_leaf': [3, 4, 5],
-                 }]
+}]
 
+parameters_ada_1 = [{
+    'n_estimators': [100, 200, 300, 400, 500, 750, 1000],
+    'learning_rate': [0.02, 0.04],
+    'loss': ['linear', 'square', 'exponential'],
+}]
+parameters_ada_2 = [{
+    'n_estimators': [50, 100, 150, 200, 250, 300, 400, 500, 700, 900, 1000],
+    'learning_rate': [0.02, 0.03, 0.04],
+    'loss': ['linear', 'square', 'exponential'],
+    'random_state': [42],
+}]
+parameters_ada_3 = [{
+    'n_estimators': [50, 100, 150, 200, 250, 300, 400, 500, 600, 700, 800, 900, 1000],
+    'learning_rate': [0.01, 0.02, 0.03, 0.04],
+    'loss': ['linear', 'square', 'exponential'],
+}]
 
+parameters_bag_1 = [{
+    'n_estimators': [100, 200, 300, 400, 500, 750, 1000],
+    'max_samples': [0.5, 0.2, 0.1],
+    'bootstrap': [True, False],
+    'bootstrap_features': [True, False],
+}]
+
+parameters_bag_2 = [{
+    'n_estimators': [50, 100, 150, 200, 250, 300, 400, 500, 700, 900, 1000],
+    'max_samples': [0.5, 0.2, 0.1],
+    'max_features': [0.5, 0.2, 0.1],
+    'bootstrap': [True, False],
+    'bootstrap_features': [True, False],
+    'warm_start': [True, False],
+}]
+parameters_bag_3 = [{
+    'n_estimators': [50, 100, 150, 200, 250, 300, 400, 500, 600, 700, 800, 900, 1000],
+    'max_samples': [0.5, 0.2, 0.1],
+    'max_features': [0.5, 0.2, 0.1],
+    'bootstrap': [True, False],
+    'bootstrap_features': [True, False],
+    'warm_start': [True, False],
+}]
+
+parameters_extr_1 = [{
+    'n_estimators': [100, 200, 300, 400, 500, 750, 1000],
+    'max_depth': [4, 6],
+    'criterion': ['mse', 'mae'],
+    'min_samples_split': [8, 10],
+}]
+
+parameters_extr_2 = [{
+    'n_estimators': [50, 100, 150, 200, 250, 300, 400, 500, 700, 900, 1000],
+    'max_depth': [4, 6, 8],
+    'criterion': ['mse', 'mae'],
+    'min_samples_split': [8, 10, 12],
+    'min_samples_leaf': [3, 4],
+}]
+parameters_extr_3 = [{
+    'n_estimators': [50, 100, 150, 200, 250, 300, 400, 500, 600, 700, 800, 900, 1000],
+    'max_depth': [4, 6, 7, 9, 10, 12, 20, 40, 50, 90, 120],
+    'criterion': ['mse', 'mae'],
+    'min_samples_split': [8, 10, 12],
+    'min_samples_leaf': [3, 4, 5],
+}]
 
 
 parameters_ann_1 = [{'batch_size': [20, 50, 32],
@@ -139,7 +196,7 @@ parameters_ann_1 = [{'batch_size': [20, 50, 32],
 parameters_ann_2 = [{'batch_size': [20, 50, 25, 32],
                      'nb_epoch': [200, 100, 300, 350],
                      'input_units': [5, 6, 10, 11, 12, ],
-                     'optimizer' : ['adam', 'rmsprop'],
+                     'optimizer': ['adam', 'rmsprop'],
 
                      }]
 parameters_ann_3 = [{'batch_size': [100, 20, 50, 25, 32],
@@ -149,15 +206,12 @@ parameters_ann_3 = [{'batch_size': [100, 20, 50, 25, 32],
                      }]
 
 
-
 parameters_lin = [{
     "fit_intercept": [True, False],
     "positive":[True, False]
 }]
 
 
-
-
 parameters_sgd_1 = [{
     'penalty': ['l1', 'l2'],
     'loss': ['squared_loss', 'huber'],
@@ -175,8 +229,8 @@ parameters_sgd_2 = [{
     'eta0': [10, 100],
 }]
 parameters_sgd_3 = [{
-    'penalty': ['l1', 'l2', 'elasticnet' ],
-    'loss': ['squared_loss', 'huber', 'epsilon_insensitive','squared_epsilon_insensitive'],
+    'penalty': ['l1', 'l2', 'elasticnet'],
+    'loss': ['squared_loss', 'huber', 'epsilon_insensitive', 'squared_epsilon_insensitive'],
     "fit_intercept": [True, False],
     'alpha':  [1e-3, 1e-4, 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9],
     'learning_rate': ['constant', 'optimal', 'invscaling', 'adaptive'],
@@ -184,8 +238,6 @@ parameters_sgd_3 = [{
 }]
 
 
-
-
 parameters_ker_1 = [{
     'alpha':  [0.1, 0.5, 0.9, 1],
     'gamma': [0.1, 0.5, 0.9, 1],
@@ -203,20 +255,12 @@ parameters_ker_3 = [{
 }]
 
 
-
-
-
-
 parameters_elas = [{
     'alpha':  [0.1, 0.5, 0.9, 1],
     'l1_ratio': [0, 0.25, 0.5, 0.75, 1],
 }]
 
 
-
-
-
-
 parameters_br = [{
     'alpha_1':  [1e-3, 1e-4, 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9],
     'alpha_2':  [1e-3, 1e-4, 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9],
@@ -225,11 +269,6 @@ parameters_br = [{
 }]
 
 
-
-
-
-
-
 parameters_lgbm_1 = [{
     'n_estimators': [100, 200, 300, 400, 500, 750, 1000],
     'min_child_weight': [1, 5, 10],
@@ -240,8 +279,8 @@ parameters_lgbm_1 = [{
 parameters_lgbm_2 = [{
     'n_estimators': [50, 100, 150, 200, 250, 300, 400, 500, 700, 900, 1000],
     'min_child_weight': [1, 5, 10],
-    'subsample': [ 0.8, 1.0],
-    'colsample_bytree': [ 0.8, 1.0],
+    'subsample': [0.8, 1.0],
+    'colsample_bytree': [0.8, 1.0],
     'reg_alpha': [0, 1e-1, 1, 2, 5, 7, 10, 50],
     'reg_lambda': [0, 1e-1, 1, 5, 10, 20, 50],
 }]
@@ -255,14 +294,6 @@ parameters_lgbm_3 = [{
 }]
 
 
-
-
-
-
-
-
-
-
 parameters_xgb_1 = [{
     'min_child_weight': [1, 5, 10],
     'n_estimators': [100, 200, 300, 400, 500, 750, 1000],
@@ -284,20 +315,13 @@ parameters_xgb_3 = [{
     'min_child_weight': [1e-3, 1e-2, 1e-1, 1, 1e1, 1e2],
     'n_estimators': [50, 100, 150, 200, 250, 300, 400, 500, 600, 700, 800, 900, 1000],
     'gamma': [1e-3, 1e-4, 0.1, 0.2, 0.3, 0.4, 0.5, 0.6, 0.7, 0.8, 0.9],
-    'subsample': [ 0.8, 1.0],
-    'colsample_bytree': [ 0.8, 1.0],
+    'subsample': [0.8, 1.0],
+    'colsample_bytree': [0.8, 1.0],
     'max_depth': [4, 5, 6, 7, 8, 9, 10, 11, 12, 15, 20, 30, 40, 50, 70, 90, 120, 150],
     'learning_rate': [0.3, 0.1, 0.03],
 }]
 
 
-
-
-
-
-
-
-
 parameters_cat = [{
     'depth': [6, 8, 10],
     'learning_rate': [0.01, 0.05, 0.1],
